class MachineStatesController < ApplicationController
  include MachineInterfaceable
  include MachineDataViewFilter
  include RxModule::Tableable

  wrap_parameters :machine_state, include: [:sn, :date, :time, :state, :comment, :addon]
  model_data_store(MachineState,
                   {create: false, read: true, update: false, delete: false, index: true},
                   {create: false, read: true, update: false, delete: false, index: true})

  def before_set_targets
    models = if filters["sn"]
               MachineState.where(machine_sn: filters["sn"])
             else
               MachineState
             end
    view_before_set_targets(models, params)
  end

  def before_filter(filter)
    view_before_filter(filter)
  end

  def add
    begin
      MachineInterfaceJobs::MachineStateInterface::AddMachineStateJob.perform_later(add_params)
    rescue => e
      Rails.logger.error e
    end
    send_machine_response
  end

  private

  def add_params
    params[:machine_state] = params[:machinestate] if params[:machinestate]
    machine_state = params.require(:machine_state).permit(:state, :comment, :addon)

    add_params = {
      machine_state: {
        state: enum_value(machine_state[:state]),
        comment: machine_state[:comment],
        addon: machine_state[:addon]
      }
    }

    add_params.merge! query_params

    add_params
  end
end
