class MaintenancesController < ApplicationController
  include MachineInterfaceable
  include MachineDataViewFilter
  include RxModule::Tableable

  wrap_parameters :maintenance_model, include: [:maintenance, :type, :status, :date, :time, :sn]
  model_data_store(Maintenance,
                   {create: false, read: true, update: false, delete: false, index: true},
                   {create: false, read: true, update: false, delete: false, index: true})

  def before_set_targets
    models = if filters["sn"]
               Maintenance.where(machine_sn: filters["sn"])
             else
               Maintenance
             end
    view_before_set_targets(models, params)
  end

  def before_filter(filter)
    view_before_filter(filter)
  end

  def add
    begin
      MachineInterfaceJobs::MaintenanceInterface::AddMaintenanceJob.perform_later(add_params)
    rescue => e
      Rails.logger.error e
    end
    send_machine_response
  end

  private

  def add_params
    params[:maintenance_model] = params[:maintenance] if params[:maintenance].is_a?(ActionController::Parameters)
    maintenance = params.require(:maintenance_model).permit(:maintenance, :type, :status)

    add_params = {
      maintenance: {
        maintenance: maintenance[:maintenance],
        maintenance_type: enum_value(maintenance[:type]),
        status: enum_value(maintenance[:status])
      }
    }

    add_params.merge! query_params

    add_params
  end
end
