import * as React from "react";
import {observer} from "mobx-react-lite";
import {MachineTypeStore} from "../../../../stores/MachineTypeStore";
import {ModelSelect} from "@rx-suite/ui";

type GroupedSelectOptions = {
    label: string,
    options: {
        label:string,
        value: string
    }[]
}

export const MachineTypeSelect: React.FunctionComponent = observer(() => {
    MachineTypeStore.getAll();

    const machineTypesOptions = React.useMemo(()=> {
        const options: GroupedSelectOptions[] = [];

        const other = {label: 'Other', options: []};

        MachineTypeStore.models.forEach((type) => {
            let category;
            if(type.category){
                category = options.find(option => option.label == type.category)
                if(!category) {
                    category = {label: type.category, options: []}
                    options.push(category);
                }
            }else {
                category = other;
            }
            category.options.push({label: type.display_name, value: type.getId()})
        });

        options.sort((a,b) => a.label.localeCompare(b.label))

        // Put 'Other' as last in the list
        options.push(other);

        return options;
    }, [MachineTypeStore.models])

    return (
        <ModelSelect
            name={"machine_type_id"}
            loading={MachineTypeStore.isLoading}
            options={machineTypesOptions}
        />
    )
})

