import * as React from "react";
import {observer} from "mobx-react-lite";
import {Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {t} from "@lingui/macro";
import {ButtonField, ModelTable} from "@rx-suite/ui";
import {ConsumableRecordDatumModel, ConsumableRecordDatumStore} from "../../../stores/ConsumableRecordDatumStore";
import {ConsumableRecordModel} from "../../../stores/ConsumableRecordStore";

type MachineConsumableDetailsDialogProps = {
    consumableRecord: ConsumableRecordModel | null;
    setConsumableRecord: React.Dispatch<React.SetStateAction<ConsumableRecordModel | null>>;
}

export const MachineConsumableDetailsDialog: React.FunctionComponent<MachineConsumableDetailsDialogProps> = observer(({consumableRecord, setConsumableRecord }) => {
    const consumableDataColumns = React.useMemo(() => {
        return [
            {
                Header: t`Data`,
                accessor: (consumableRecordDatum: ConsumableRecordDatumModel) => consumableRecordDatum,
                id: '_name',
                Cell: (cellInfo: {value: ConsumableRecordDatumModel}) => {
                    return cellInfo.value.resolved_name;
                },
                filterable: false,
                sortable: false
            },
            {
                Header: t`Value`,
                accessor: 'value',
                Cell: (cellInfo: {value: string}) => {
                    if (!cellInfo.value) {
                        return t`No Data`;
                    }
                    return cellInfo.value;
                },
                filterable: false,
                sortable: false
            }
        ];
    }, [])

    const handleClose = React.useCallback(() => {
        setConsumableRecord(null);
    }, [setConsumableRecord]);

    if(!consumableRecord){
        return null;
    }

    return (
        <Dialog open={true} onClose={handleClose} aria-labelledby="form-dialog-title" maxWidth={"sm"} fullWidth>
            <DialogTitle id="form-dialog-title">{consumableRecord.resolved_name}</DialogTitle>
            <DialogContent>
                <ModelTable
                    store={ConsumableRecordDatumStore}
                    columns={consumableDataColumns}
                    showPagination={false}
                    sortable={false}
                    defaultPageSize={5}
                    defaultFiltered={[{id: "consumable_record_id", value: consumableRecord.id}]}
                    suppressActionColumn
                    suppressWrapper
                />
                <DialogActions>
                    <ButtonField
                        text={t`Close`}
                        onClick={handleClose}
                        color={'secondary'}
                        variant={'text'}
                    />
                </DialogActions>
            </DialogContent>
        </Dialog>
    )
})