import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {MachineDataViewTab} from "../MachineDataViewTab";
import {CalibrationStore} from "../../../stores/CalibrationStore";
import {makeColumn} from "@rx-suite/ui";
import {MachineDataViewPanelProps} from "../MachineDataView";
import {useServerTimeColumn} from "../../../hooks/table_columns/useServerTimeColumn";


export const CalibrationsPanel: React.FunctionComponent<MachineDataViewPanelProps> = observer((props) => {
    const {machine} = props;

    const columns = [
        {Header: t`Machine Calibrations`, columns: [
                makeColumn('target', t`Target`, "string"),
                makeColumn('target_name', t`Target Name`, "string"),
                makeColumn('calibration_type', t`Calibration Type`, "string"),
                makeColumn('sub_type', t`Sub Type`, "string"),
                makeColumn('mode', t`Mode`, "string"),
                makeColumn('user', t`User`, "string"),
                useServerTimeColumn()
            ]
        }];

    return (
        <MachineDataViewTab
            columns={columns}
            machine={machine}
            enabledKey={'calibration'}
            tabName={'Calibration'}
            store={CalibrationStore}
            exportedFileName={'Calibrations.csv'}
            exportEndpoint={'calibrations'}
        />
    );
});