import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {MachineDataViewTab} from "../MachineDataViewTab";
import {ErrorStore} from "../../../stores/ErrorStore";
import {makeColumn, SelectField} from "@rx-suite/ui";
import {Filter, ReactTableFunction} from "react-table";
import {MachineDataViewPanelProps} from "../MachineDataView";
import {useServerTimeColumn} from "../../../hooks/table_columns/useServerTimeColumn";


export const ErrorsPanel: React.FunctionComponent<MachineDataViewPanelProps> = observer((props) => {
    const {machine} = props;

    const columns = [
        {Header: t`Machine Errors`, columns: [
                makeColumn('error', t`Error`, "string"),
                makeColumn('errno', t`Err No.`, "string"),
                {
                    Header: t`Error Type`,
                    id: 'errortype',
                    accessor: 'errortype',
                    filterable: true,
                    Filter: ({ filter, onChange }: { filter: Filter, onChange: ReactTableFunction}) => (
                        <SelectField
                            options={
                                [
                                    {label: "unknown", value: 0},
                                    {label: "info", value: 1},
                                    {label: "alarm", value: 2},
                                    {label: "error", value: 3},
                                    {label: "all", value: ""}
                                ]
                            }
                            onChange={(name, value) => onChange(value)}
                            value={filter ? filter.value : ""}
                        />
                    )
                },
                {
                    Header: t`Status`,
                    id: 'status',
                    accessor: 'status',
                    filterable: true,
                    Filter: ({ filter, onChange }: { filter: Filter, onChange: ReactTableFunction}) => (
                        <SelectField
                            options={
                                [
                                    {label: "raised", value: 0},
                                    {label: "acknowledged", value: 1},
                                    {label: "finished", value: 2},
                                    {label: "all", value: ""}
                                ]
                            }
                            onChange={(name, value) => onChange(value)}
                            value={filter ? filter.value : ""}
                        />
                    )
                },
                useServerTimeColumn()
            ]
        }];

    return (
        <MachineDataViewTab
            columns={columns}
            machine={machine}
            enabledKey={'error'}
            tabName={'Error'}
            store={ErrorStore}
            exportedFileName={'Errors.csv'}
            exportEndpoint={'errors'}
        />
    );
});
