import {attribute, DataStore, Model, model} from "@rx-suite/data";

import {t} from "@lingui/macro";
import * as yup from 'yup';
import {override} from "mobx";


@model({
    transportLayer: '/api/machine_processes',
    permissionTarget: "MachineProcess",
    routingInfo: {
        list: '/settings/machine_processes',
        create: '/settings/machine_processes/create',
        read: '/settings/machine_processes/:id/read',
        update: '/settings/machine_processes/:id/edit'
    }
})

export class MachineProcessModel extends Model {

    @attribute({ label: t`Display Name`, validation: yup.string().required() })
    display_name = "";

    @attribute({ label: t`Code`, validation: yup.string().required() })
    code = "";

    @attribute({ label: t`Rank`, validation: yup.number().min(0).required() })
    rank = 0;

    @attribute({ label: t`System Default`, validation: yup.boolean().required() })
    system_default = false;

    @override
    get isUserDeletable() {
        return !this.system_default;
    }

    constructor() {
        super();
        super.setup();
    }
}

export const MachineProcessStore = MachineProcessModel.store as unknown as DataStore<MachineProcessModel>;