module MachineInterfaceJobs
  module Base
    class JobDataJob < MachineInterfaceJob

      # Base Class for machine interface jobs that also manipulate or create job data

      def perform(add_params)
        resolve_job(add_params[:job])
        super(add_params)
      end

      def resolve_job(job_params)
        @job = if job_params.blank?
                nil
              else
                side_num = Sideable.side_letter_to_side_num(job_params[:side])
                FindHelpers::JobFinders.find_active_or_create_by_number_and_side_num(job_params[:job_number], side_num)
              end
        raise InvalidMachineInterfaceData if job_required? && @job.nil?

        match_job_to_order unless @job.nil?

        @job
      end

      def job_required?
        true
      end

      private

      def match_job_to_order
        return if @job.order
        return unless JobSetting.instance.auto_pair_job

        other_side = FindHelpers::JobFinders.active_with_number_and_side_num(@job.number, @job.opposite_side_num)

        if other_side.nil?
          new_order_for_jobs([@job])
        else
          if other_side.order.nil?
            new_order_for_jobs([@job, other_side])
          else
            @job.order = other_side.order
            @job.save!
          end
        end
      end

      def new_order_for_jobs(jobs)
        order = Order.new(job_number: jobs[0].number)
        order.jobs = jobs
        order.save!
      end
    end
  end
end

