module MachineKpiCalculator
  class IdleTimeCounts < EnergyUsageBreakdown
    include IntervalBuilder
    include BucketCalculator

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
        kpi = IdleTimeCounts.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :idle_counts,
          handler: :idle_counts,
          params: {}
        }
      ]
    end

    def idle_counts
      MachineKpi.idle_time_runs(start_time, end_time, machine_ids, {})
    end

    def build_results
      raise NotImplementedError
    end

    def build_results_per_machine
      buckets_with_idle_count
    end

    def buckets_with_idle_count
      time_buckets = time_buckets(start_time, end_time, timeframe)
      results = {}

      time_buckets.each_with_index do |(period, value), index|
        @machine_ids.each do |id|
          results[period] = {} if results[period].nil?
          results[period][id] = {count: 0, duration: 0, energy: 0} if results[period][id].nil?
        end
      end

      data[:idle_counts].each do |id, machine_idles|
        machine_idles.map do |machine_idle|

          time_buckets.each_with_index do |(period, value), index|

            # Edge Case: If a machine_idle start and end dates spans 2 time buckets, place the data
            # in the latest bucket it will fit to avoid duplication of data on 2 or more buckets
            next_period = time_buckets.keys[index + 1]
            if next_period.nil?
              idle_within_current_bucket = (machine_idle[:end] >= period)
            else
              idle_within_current_bucket = (machine_idle[:end] >= period) && (machine_idle[:end] <= next_period)
            end

            if idle_within_current_bucket
              results[period][id][:count] += 1
              results[period][id][:duration] += machine_idle[:duration][:count]
              results[period][id][:energy] += machine_idle[:energy]
            end
          end
        end
      end

      results
    end

    def as_percent(results)
      raise NotImplementedError
    end
  end
end
