module MachineTypes
    class MachineTypeTemplate
      class << self
        def seed
          machine_type = get_machine_type

          return puts "Machine Type #{display_name} (version #{machine_type.seed_version}) up to date - skipping seed." if machine_type.seed_version >= seed_version

          puts "Updating Machine Type #{display_name} (version #{machine_type.seed_version}) to seed version #{seed_version}"

          error_filters.each do |filter_def|
            resolved_group_code = "#{name}_#{filter_def[:group_code]}"

            if ErrorFilter.find_by(group_code: resolved_group_code).nil?
              machine_type.error_filters.build({
                   group_code: resolved_group_code,
                   name: filter_def[:name],
                   error_codes: filter_def[:error_codes],
                   system_default: true,
                   behaviour: filter_def[:behaviour],
                   replace_name: filter_def[:replace_name]
                })
            end
          end

          abort_filters.each do |filter_def|
            resolved_group_code = "#{name}_#{filter_def[:group_code]}"

            if AbortFilter.find_by(group_code: resolved_group_code).nil?
              machine_type.abort_filters.build({
                                                 group_code: resolved_group_code,
                                                 name: filter_def[:name],
                                                 regexps: filter_def[:regexps],
                                                 system_default: true,
                                                 behaviour: filter_def[:behaviour],
                                                 replace_name: filter_def[:replace_name]
                                               })
            end
          end

          apply_patch(machine_type)

          machine_type.seed_version = seed_version

          machine_type.save!
          puts "Machine Type #{display_name} updated to seed version #{seed_version}"
        end

        def seed_version
          2
        end

        def apply_patch(machine_type)
          # Version 2 introduced machine processes
          machine_type.machine_process = machine_process
        end

        def get_machine_type
          machine_type = MachineType.find_by_name(name)
          if machine_type.nil?
            machine_type = MachineType.create(
              name: name,
              display_name: display_name,
              seed_version: 0,
              system_default: true,
              category: category,
            )
          end
          machine_type
        end

        def display_name
          raise NotImplementedError
        end

        def name
          raise NotImplementedError
        end

        def error_filters
          []
        end

        def abort_filters
          []
        end

        def image_url
          return nil if image_name.nil?
          "#{category}/#{image_name}"
        end

        def image_name
          nil
        end

        def translator_class
          nil
        end

        def machine_process
          nil
        end

        concerning :StaticData do
          def interfaces
            {
              machine_state: true,
              job_state: true,
              error: true,
              maintenance: true,
              process_data: true,
              event: true,
              calibration: true
            }
          end

          def has_consumable_data?
            !consumable_data_params.nil?
          end

          def consumable_data_params
            nil
          end

          def has_machine_manuals?
            !machine_manuals.nil?
          end

          def machine_manuals
            nil
          end

          def has_energy_consumptions?
            !energy_consumptions.nil?
          end

          def energy_consumptions
            nil
          end
        end
      end
    end
end

