module ReportComponents
  class MachineEnergyUsageOverTime < ReportComponent
    include ReportComponentHelpers
    include KpiHelpers
    include DataHelpers

    def component_id
      'machine_energy_usage_over_time'
    end

    def component_type
      'line'
    end

    def generate(args)
      @machine_state_energy = MachineKpi.energy_usage_between(start_time,
                                                             end_time,
                                                             timeframe,
                                                             machine_ids,
                                                             options: args)

      productive_usage = extract_target_usage("productive")
      unproductive_usage = extract_target_usage("unproductive")

      throughput = MachineKpi.throughput_between(start_time, end_time, timeframe, machine_ids, options: args)

      largest_usage = [productive_usage.values.max, unproductive_usage.values.max].max

      data = {
        series: [
          build_series_for_kpi_bucket("Productive Usage", productive_usage, 'line', :format_productive),
          build_series_for_kpi_bucket("Unproductive Usage", unproductive_usage, 'line', :format_unproductive),
          build_series_for_kpi_bucket('Throughput', throughput, 'bar', :format_throughput),
        ],
        max_usage: largest_usage.ceil,
        colors: [PRODUCTIVITY_COLORS[:great], PRODUCTIVITY_COLORS[:ok], PRODUCTIVITY_COLORS[:throughput]]
      }

      data
    end

    def format_productive(bucket_value)
      bucket_value
    end

    def format_unproductive(bucket_value)
      bucket_value
    end

    def format_throughput(bucket_value)
      bucket_value[:count]
    end

    def extract_target_usage(target_usage)
      extracted_data = {}
      @machine_state_energy.values.map do |states_in_bucket|
        states_in_bucket.each do |bucket, states|
          extracted_data[bucket] ||= 0
          if target_usage == "productive"
            extracted_data[bucket] += states[:processing][:count]
          else
            unproductive_in_bucket = 0
            states.each do |state, value|
              next if state == :processing
              unproductive_in_bucket += value[:count]
            end
            extracted_data[bucket] += unproductive_in_bucket
          end
          extracted_data[bucket] = extracted_data[bucket].round(2)
        end
      end

      extracted_data
    end

  end
end