module ReportComponents
  class MachineEnergyUsagePerLens < ReportComponent
    include ReportComponentHelpers
    include KpiHelpers
    include DataHelpers

    def component_id
      'machine_energy_usage_per_lens'
    end

    def component_type
      'line'
    end

    def generate(args)
      @machine_state_energy = MachineKpi.energy_usage_between(start_time,
                                                            end_time,
                                                            Timeframe::ALL,
                                                            machine_ids,
                                                            options: args)

      @job_states = MachineKpi.job_state_breakdown_between(start_time,
                                                           end_time,
                                                           Timeframe::ALL,
                                                           machine_ids,
                                                           options: args)

      total_usage, productive_usage, unproductive_usage, total_lens_count = build_data

      energy_per_job = total_lens_count.zero? ? 0 : (total_usage / total_lens_count).round(2)
      productive_usage_per_lens = total_lens_count.zero? ? 0 : (productive_usage / total_lens_count).round(2)
      unproductive_usage_per_lens = total_lens_count.zero? ? 0 : (unproductive_usage / total_lens_count).round(2)

      {
        energy_per_job: energy_per_job,
        total_jobs: total_lens_count,
        productive_usage: productive_usage_per_lens,
        unproductive_usage: unproductive_usage_per_lens
      }
    end

    def build_data
      total_usage = 0  # sum of all energy used for all states and machines
      productive_usage = 0  # sum of energy in PROCESSING state for all machines
      unproductive_usage = 0  # sum of energy of all other states (not PROCESSING) for all machines
      total_lens_count = 0

      @machine_state_energy.values.map do |states|
        states.each do |state, value|
          if state.to_s == "processing"
            productive_usage += value[:count]
          else
            unproductive_usage += value[:count]
          end
          total_usage += value[:count]
        end
      end

      @job_states.each do |key, value|
        next unless key == :finished
        total_lens_count += value[:count]
      end

      [total_usage.round(2), productive_usage.round(2), unproductive_usage.round(2), total_lens_count]
    end
  end
end