module ReportComponents
  class MachineErrorTrendsLine < ReportComponent
    include ReportComponentHelpers

    def component_id
      'machine_error_trends'
    end

    def component_type
      'line'
    end

    def generate(args)
      return set_no_data('This machine type does not collect errors.') unless machine_targets_collect_error(machine_ids)

      error_trends = MachineKpi.error_trends_between(start_time, end_time, timeframe, machine_ids, options: args)

      return set_no_data('No errors during reporting period') if error_trends.blank?

      aggregated_error_trends = {}
      total_error_count_hash = {}
      error_trends.each do |machine_id, error_trend|
        error_trend.each do |error, data|
          aggregated_error_trends[error] = {} if aggregated_error_trends[error].blank?
          data.each do |time, values|
            aggregated_error_trends[error][time] = { :count => 0 } if aggregated_error_trends[error][time].blank?
            aggregated_error_trends[error][time][:count] += values[:count]
            total_error_count_hash[time] = 0 if total_error_count_hash[time].blank?
            total_error_count_hash[time] += values[:count]
          end
        end
      end

      aggregated_error_trends.each do |error, time_hash|
        time_hash.each do |ck, cv|
          aggregated_error_trends[error][ck][:percent] = Tools.percentage_maker(cv[:count], total_error_count_hash[ck], 0)
        end
      end

      data = {
        series: aggregated_error_trends.map { |error, data|  build_series_for_kpi_bucket(error, data, 'line', :format_kpi_bucket_value)},
      }

      data[:colors] = color_for_series(aggregated_error_trends.size) if args[:colorize_series]

      data
    end

    def format_kpi_bucket_value(bucket_value)
      bucket_value[:percent]
    end
  end
end