module ReportComponents
  class MachineProductivityOverview < ReportComponent
    include ReportComponentHelpers
    include KpiHelpers
    include DataHelpers

    def component_id
      'machine_productivity_overview'
    end

    def component_type
      'bar'
    end

    def generate(args)
      @states = MachineKpi.state_breakdown_between(start_time,
                                                   end_time,
                                                   Timeframe::ALL,
                                                   machine_ids,
                                                   options: args)

      categories, series, colors = build_data

      return set_no_data('No machine states during reporting period') if @states.blank?

      {
        categories: categories,
        series: series,
        colors: colors
      }
    end

    def build_data
      productive_states = [:processing, :off]

      categories = []
      series = [{name: "Productive Usage", data: []}, {name: "Unproductive Usage", data: []}, {name: "Machine Off", data: []}]

      @states.each_with_index do |value, index|
        machine = Machine.find_by_id(value[0])
        categories.push(machine&.ensured_name || value[0])

        productive_percentage = value[1][:processing][:percent].round(2)
        off_percentage = value[1][:off][:percent].round(2)
        unproductive_states = value[1].select {|k, v| !productive_states.include?(k)}
        unproductive_percentage = unproductive_states.map {|k, v| v[:percent]}.sum.round(2)

        series[0][:data][index] = productive_percentage
        series[1][:data][index] = unproductive_percentage
        series[2][:data][index] = off_percentage
      end

      colors = [PRODUCTIVITY_COLORS[:great], PRODUCTIVITY_COLORS[:ok], PRODUCTIVITY_COLORS[:off]]

      [categories, series, colors]
    end
  end
end