module ReportComponents
  class MachineProductivityScore < ReportComponent
    include ReportComponentHelpers
    include KpiHelpers
    include DataHelpers

    def component_id
      'machine_productivity_score'
    end

    def component_type
      'score'
    end

    def generate(args)
      @states = MachineKpi.state_breakdown_between(start_time,
                                                   end_time,
                                                   Timeframe::ALL,
                                                   machine_ids,
                                                   options: args)

      score, color, score_text = build_data

      return set_no_data('No machine states during reporting period') if @states.blank?

      {
        score: score,
        color: color,
        score_text: score_text
      }
    end

    def build_data
      score = @states[:processing][:percent]
      color = PRODUCTIVITY_COLORS[:poor] # DARK RED (score: <50%)
      score_text = 'POOR'
      if score >= 50 # YELLOW (score: 50% - 69%)
        color = PRODUCTIVITY_COLORS[:ok]
        score_text = 'OK'
      end
      if score >= 70 # GREEN (score: 70% - 89%)
        color = PRODUCTIVITY_COLORS[:good]
        score_text = 'GOOD'
      end
      if score >= 90 # DARK GREEN (score: >00%)
        color = PRODUCTIVITY_COLORS[:great]
        score_text = 'GREAT'
      end

      [score, color, score_text]
    end
  end
end