class RemoveStaticDataFromMachineTypes < ActiveRecord::Migration[6.1]
  class MachineType < ActiveRecord::Base
  end

  def up
    remove_column :machine_types, :job_state_enabled
    remove_column :machine_types, :error_enabled
    remove_column :machine_types, :maintenance_enabled
    remove_column :machine_types, :process_data_enabled
    remove_column :machine_types, :machine_state_enabled
    remove_column :machine_types, :event_data_enabled
    remove_column :machine_types, :calibration_data_enabled
    remove_column :machine_types, :image_url
    remove_column :machine_types, :translator_class
  end

  def down
    add_column :machine_types, :job_state_enabled, :boolean, default: false
    add_column :machine_types, :error_enabled, :boolean, default: false
    add_column :machine_types, :maintenance_enabled, :boolean, default: false
    add_column :machine_types, :process_data_enabled, :boolean, default: false
    add_column :machine_types, :machine_state_enabled, :boolean, default: false
    add_column :machine_types, :event_data_enabled, :boolean, default: false
    add_column :machine_types, :calibration_data_enabled, :boolean, default: false
    add_column :machine_types, :image_url, :text
    add_column :machine_types, :translator_class, :string, null: true

    MachineType.find_each do |machine_type|
      static_data = static_machine_type_data[machine_type.name]

      machine_type.update(
        {
          job_state_enabled: static_data[:interfaces][:job_state],
          error_enabled: static_data[:interfaces][:error],
          maintenance_enabled: static_data[:interfaces][:maintenance],
          process_data_enabled: static_data[:interfaces][:process_data],
          machine_state_enabled: static_data[:interfaces][:machine_state],
          event_data_enabled: static_data[:interfaces][:event],
          calibration_data_enabled: static_data[:interfaces][:calibration],
          image_url: static_data[:image_url],
          translator_class: static_data[:translator_class]
        }
      )
    end
  end

  def static_machine_type_data
    {
      "art_blocker_a" => {
        image_url: 'blocker/art_blocker_a.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "art_blocker_m" => {
        image_url: 'blocker/art_blocker_m.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: false,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "art_block_pod" => {
        image_url: 'blocker/art_block_pod.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "layoutblocker_pra" => {
        image_url: 'blocker/layoutblocker_pra.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: false,
          process_data: false,
          event: false,
          calibration: false
        }
      },
      "1200_dlx_2" => {
        image_url: 'box_coater/1200_dlx_2.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "mc_280_x" => {
        image_url: 'box_coater/mc_280_x.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "mc_380_x_2" => {
        image_url: 'box_coater/mc_380_x2.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "1500_x" => {
        image_url: 'box_coater/1500_x.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "art_deblocker_a" => {
        image_url: 'deblocker/art_deblocker_a.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: false,
          process_data: true,
          event: false,
          calibration: false
        }
      },
      "art_deblocker_a_2" => {
        image_url: 'deblocker/art_deblocker_a.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: false
        }
      },
      "art_deblocker_m" => {
        image_url: 'deblocker/art_deblocker_m.png',
        interfaces: {
          machine_state: false,
          job_state: false,
          error: false,
          maintenance: false,
          process_data: false,
          event: false,
          calibration: false
        }
      },
      "mei_edger" => {
        image_url: nil,
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: false,
          process_data: true,
          event: false,
          calibration: false
        },
        translator_class: 'MeiEdger'
      },
      "lens_engraver_uv" => {
        image_url: nil,
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "vft_macro" => {
        image_url: 'generator/vft_macro.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "vft_macro_e" => {
        image_url: 'generator/vft_macro_e.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "vft_orbit" => {
        image_url: 'generator/vft_orbit.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "vft_orbit_2" => {
        image_url: 'generator/vft_orbit_2.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "vft_orbit_2e" => {
        image_url: 'generator/vft_orbit_2e.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "other" => {
        image_url: nil,
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "duo_flex" => {
        image_url: 'polisher/duo_flex.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "multi_flex" => {
        image_url: 'polisher/multi_flex.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "multi_flex_2" => {
        image_url: 'polisher/multi_flex_2.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "multi_flex_2e" => {
        image_url: 'polisher/multi_flex_2e.png',
        interfaces: {
          machine_state: true,
          job_state: true,
          error: true,
          maintenance: true,
          process_data: true,
          event: true,
          calibration: true
        }
      },
      "toro_flex" => {
        image_url: 'polisher/toro_flex.png',
        interfaces: {
          machine_state: false,
          job_state: false,
          error: false,
          maintenance: false,
          process_data: false,
          event: false,
          calibration: false
        }
      }
    }
  end
end
